
Variable dictionary
----------------------

.. automodule:: flax.core.variables
.. autoclass:: flax.linen.Variable

**Summary**

.. currentmodule:: flax.linen
.. autosummary::
  :toctree: _autosummary

  Variable